Class: Tui::Layout
- Inherits:
-
Object
- Object
- Tui::Layout
- Defined in:
- lib/tui/layout.rb
Overview
Main window layout.
It represents the main window of the application's TUI
Instance Method Summary collapse
-
#initialize(&block) ⇒ Layout
constructor
Internal content is expected to be rendered each time => should be callable.
-
#render ⇒ Object
Render content to produce a frame, which could be print -ed.